==> slush-coui-0.6.5.tgz: package/slushfile.js <==
var gulp = require('gulp')
  , install = require('gulp-install')
  , conflict = require('gulp-conflict')
  , template = require('gulp-template')
  , gulpif = require('gulp-if')
  , inquirer = require('inquirer')
  ;

var condition = function (file) {
  return file.path.indexOf('package.json') !== -1
};

/**
 * 日期格式化
 * @param {String} format 待转换的日期格式字符串 eg：yyyy-MM-dd
 */
  // eslint-disable-next-line
Date.prototype.format = function(format) {
  if (this.getMonth() > -1) {
    let o = {
      'M+': this.getMonth() + 1, // month
      'd+': this.getDate(), // day
      'h+': this.getHours(), // hour
      'm+': this.getMinutes(), // minute
      's+': this.getSeconds(), // second
      'q+': Math.floor((this.getMonth() + 3) / 3), // quarter
      'S': this.getMilliseconds() // millisecond
    };

    if (/(y+)/.test(format)) {
      format = format.replace(RegExp.$1, (this.getFullYear() + '').substr(4 - RegExp.$1.length));
    }

    for (let k in o) {
      if (new RegExp('(' + k + ')').test(format)) {
        format = format.replace(RegExp.$1, RegExp.$1.length === 1 ? o[k] : ('00' + o[k]).substr(('' + o[k]).length));
      }
    };
  } else {
    format = '';
  }
  return format;
};

/**
* 创建模块
*/
gulp.task('module', function(done) {
  inquirer.prompt([
    {type: 'input', name: 'name', message: '请输入功能名称(单词间中横杠分割)', default: gulp.args.join(' ')} // Get module name from arguments by default
  ]).then(function(answers) {
    var name = answers.name;
    gulp.src(__dirname + '/templates/module/example-base/**')  // Note use of __dirname to be relative to generator
    .pipe(template({                                           // Lodash template support
      name: name,
      current: new Date().format('yyyy/MM/dd hh:mm:ss')
    }))
    .pipe(conflict('./'))                                     // Confirms overwrites on file conflicts
    .pipe(gulp.dest('./src/' + name))                         // Without __dirname here = relative to cwd
    .on('end', function() {
      done();                                                 // Finished!
    })
    .resume();
  });
});

/**
* 创建工程
*/
gulp.task('default', function (done) {
  inquirer.prompt([
    {type: 'input', name: 'name', message: '请输入项目名称(单词间中横杠分割)', default: gulp.args.join(' ')} // Get app name from arguments by default
  ]).then(function (answers) {
    gulp.src([__dirname + '/templates/simple/**', __dirname + '/templates/simple/.*'])  // Note use of __dirname to be relative to generator
    .pipe(gulpif(condition, template(answers))) // Lodash template support
    .pipe(conflict('./'))                       // Confirms overwrites on file conflicts
    .pipe(gulp.dest('./' + answers.name))       // Without __dirname here = relative to cwd
    // .pipe(install())                         // Run `bower install` and/or `npm install` if necessary
    .on('end', function () {
      done();                                   // Finished!
    })
    .resume();
  });
});

==> slush-coui-2.0.2.tgz: package/slushfile.js <==
var gulp = require('gulp')
  , install = require('gulp-install')
  , conflict = require('gulp-conflict')
  , template = require('gulp-template')
  , gulpif = require('gulp-if')
  , inquirer = require('inquirer')
  ;

var condition = function (file) {
  return file.path.indexOf('package.json') !== -1
};

/**
 * 日期格式化
 * @param {String} format 待转换的日期格式字符串 eg：yyyy-MM-dd
 */
  // eslint-disable-next-line
Date.prototype.format = function(format) {
  if (this.getMonth() > -1) {
    let o = {
      'M+': this.getMonth() + 1, // month
      'd+': this.getDate(), // day
      'h+': this.getHours(), // hour
      'm+': this.getMinutes(), // minute
      's+': this.getSeconds(), // second
      'q+': Math.floor((this.getMonth() + 3) / 3), // quarter
      'S': this.getMilliseconds() // millisecond
    };

    if (/(y+)/.test(format)) {
      format = format.replace(RegExp.$1, (this.getFullYear() + '').substr(4 - RegExp.$1.length));
    }

    for (let k in o) {
      if (new RegExp('(' + k + ')').test(format)) {
        format = format.replace(RegExp.$1, RegExp.$1.length === 1 ? o[k] : ('00' + o[k]).substr(('' + o[k]).length));
      }
    };
  } else {
    format = '';
  }
  return format;
};

/**
* 创建模块
*/
gulp.task('module', function(done) {
  inquirer.prompt([
    {type: 'input', name: 'name', message: '请输入功能名称(单词间中横杠分割)', default: gulp.args.join(' ')} // Get module name from arguments by default
  ]).then(function(answers) {
    var name = answers.name
      , date = new Date()
      ;

    gulp.src(__dirname + '/templates/module/example-base/**')  // Note use of __dirname to be relative to generator
    .pipe(template({                                           // Lodash template support
      name: name,
      current: date.format('yyyy/MM/dd hh:mm:ss'),
      timestamp: date.getTime()
    }))
    .pipe(conflict('./'))                                     // Confirms overwrites on file conflicts
    .pipe(gulp.dest('./src/' + name))                         // Without __dirname here = relative to cwd
    .on('end', function() {
      done();                                                 // Finished!
    })
    .resume();
  });
});

/**
* 创建工程
*/
gulp.task('default', function (done) {
  inquirer.prompt([
    {type: 'input', name: 'name', message: '请输入项目名称(单词间中横杠分割)', default: gulp.args.join(' ')} // Get app name from arguments by default
  ]).then(function (answers) {
    gulp.src([__dirname + '/templates/simple/**', __dirname + '/templates/simple/.*'])  // Note use of __dirname to be relative to generator
    .pipe(gulpif(condition, template(answers))) // Lodash template support
    .pipe(conflict('./'))                       // Confirms overwrites on file conflicts
    .pipe(gulp.dest('./' + answers.name))       // Without __dirname here = relative to cwd
    // .pipe(install())                         // Run `bower install` and/or `npm install` if necessary
    .on('end', function () {
      done();                                   // Finished!
    })
    .resume();
  });
});
